#
# spec file for package libdfp
#
# Copyright (c) 2020 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Url:            https://github.com/libdfp/libdfp

Name:           libdfp
Summary:        Decimal floating point library
License:        LGPL-2.1-only
Group:          Development/Libraries/C and C++
Version:        1.0.15
Release:        lp152.2.6.1
Source:         libdfp-%{version}.tar.bz2
Source99:       baselibs.conf
Patch1:         libdfp-fix-install-perms.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  glibc-devel
BuildRequires:  python3
ExclusiveArch:  s390 s390x ppc64le x86_64

%description
A library containing support routines for calculating with and printing
decimal floating point values.



%package -n libdfp1
Summary:        Decimal floating point library
Group:          System/Libraries

%description -n libdfp1
A library containing support routines for calculating with and printing
decimal floating point values.



%package devel
Summary:        Decimal floating point library
Group:          Development/Libraries/C and C++
Requires:       libdfp1 = %{version}

%description devel
A library containing support routines for calculating with and printing
decimal floating point values.


%package devel-static
Summary:        Decimal floating point static library
Group:          Development/Libraries/C and C++
Requires:       libdfp-devel = %{version}

%description devel-static
A static library containing support routines for calculating with and printing
decimal floating point values.




%prep
%setup -n %{name}
%patch1 -p1

%build
# We ship a static library, so use fat LTO
%global _lto_cflags %{?_lto_cflags} -ffat-lto-objects
export CFLAGS="$RPM_OPT_FLAGS"
mkdir build
cd build
%define _configure ../configure
%configure
make %{?_smp_mflags}
cd ..

%install
cd build
make DESTDIR=%{buildroot} install
rm -rf %{buildroot}/usr/share/doc/dfp
find %{buildroot} -name '*decnumber*' | xargs rm -rf
find $RPM_BUILD_ROOT/%{_libdir} -name '*.a' | xargs chmod 644

%clean
rm -rf $RPM_BUILD_ROOT

%post -n libdfp1 -p /sbin/ldconfig

%postun -n libdfp1 -p /sbin/ldconfig

%files -n libdfp1
%defattr(-,root,root)
%{_libdir}/lib*so.*
%{_libdir}/libdfp-*.so

%files devel
%defattr(-,root,root)
%{_includedir}/dfp
%{_libdir}/libdfp.so
%{_libdir}/pkgconfig/libdfp.pc

%files devel-static
%defattr(-,root,root)
%{_libdir}/libdfp.a

%changelog
* Tue Oct 27 2020 matz@suse.com
- Remove special cases for obsolete ppc/ppc64 architecture
- Fix installed files, don't build two variants on s390x [bsc#1178010]
- Add libdfp-fix-install-perms.diff to fix permissions of data files
- Enable fat LTO for the static archive
* Mon Sep 14 2020 matz@suse.com
- Upgrade to version 1.0.15 [jsc#SLE-13839, jsc#SLE-14885, jsc#IBM-704,
  jsc#SLE-15622, jsc#SLE-14722, jsc#IBM-703, jsc#ECO-2376]
  * Add support for arch13/z15 s390 CPUs
  * Integrate libdecnumber into build
  * Fix spurious integer overflow warnings
  * sin/cos: more correctly compute the requested value
  * Fix and test ldexp
  * Add native expd128, logd128
  * Add fminmagN function as TS18661 recommends
- Enable build for x86_64
- Fix _smp_mflags rpm macro typo
* Fri Jan 17 2020 matz@suse.com
- Upgrade to version 1.0.14 [jsc#SLE-7641 aka jsc#SLE-7401]
  Since 1.0.13:
  * enable POWER9 build
  * add support for arch12/z14 s390 CPUs
  * add hardware implementations on s390 for:
    islessgreaterd32|64|128, isunorderedd32|64|128, islessequald32|64|128,
    islessd32|64|128, isgreaterequald32|64|128, isgreaterd32|64|128,
    fdimd32|64|128, fmaxd32|64|128, fmind32|64|128, signbitd32|64|128,
    llquantexpd32|64|128, samequantumd32|64|128, quantumd32|64|128,
    issignalingd32|64|128, isinfd32|64|128, isnand32|64|128,
    isnormald32|64|128, isfinited32|64|128, fpclassifyd32|64|128,
    copysignd32|64|128, fabsd32|64|128, llrintd32|64|128,
    lrintd32|64|128, llround32|64|128, lroundd32|64|128,
    roundevend32|64|128, roundd32|64|128, truncd32|64|128,
    floord32|64|128, ceild32|64|128, rintd32|64|128,
    nearbyintd[32|64|128], quantized32|64|128
  * add more tests or fix them for above
  Since 1.0.12:
  * Implement ti <-> Decimal conversions
  * Add mantissa extraction functions
  * Optimize 128b conversions
  * Add support for newer s390 cpus
  Since 1.0.11:
  * Print correct number of digits testing ulps
  * Ensure hardware dfp is disabled with sw only
  * Fix edge case with strtod*
  * libdfp: powerpc: Fix fabsd128 implementation
  * Fix the usage of mfcr extended mnemonic
  Since 1.0.10:
  * Extend the release and build process and fix various
    compile problems
  Since 1.0.9.1:
  * Added BID support for x86_64 and x86
  * Fixes to avoid external PLT calls to internal supplied symbols
  * Add optimized fabsd[32|64|128], and copysignd[32|64|128] for
    PowerPC with DFP hardware support
* Mon Dec  4 2017 rguenther@suse.com
- Adjust according to packaging conventions, add libdfp-devel-static
  for static library.
* Tue Sep  2 2014 ro@suse.de
- sanitize release line in specfile
* Wed Mar  5 2014 matz@suse.com
- Upgrade to version 1.0.9.1.  [bnc #866739]
  Support for ppc64le and power8.
  Fix for isinfd[32|64|128] (return +1 for inf, -1 for -inf).
  Fix finited.
  New functions llogbd[32|64|128], roundevend[32|64|128],
  quantumd[32|64|128], new macro issignaling.  All based on
  draft TS 18661.
  Optimized ceild[32|64|128], truncd[32|64|128], floord[32|64|128],
  nearbyintd[32|64|128], roundd[32|64|128], samequantumd[32|64|128]
  for PowerPC with DFP hardware.
* Fri Dec  7 2012 matz@suse.com
- Upgrade to version 1.0.8.  [fate #314087]
  Minor bug fixes all over, add c++ header decimal/decimal,
  add dfp/float.h defining _Decimal[32|64|128] if necessary.
* Wed Aug 17 2011 dmueller@suse.de
- add baselibs.conf to sources
* Fri Jul  1 2011 matz@suse.de
- Upgrade to version 1.0.7.  [fate #311678]
  Added isfinite() and deprecated finite(), per POSIX.
  Fixed locale base printf.
  Fixed printf_dfp() to work for several hundred use cases
    which previously produced partially correct output.
  Fixed strtod*() for all test suite cases.
  Fixed classification function (fpclassifyd*()).
  Fixed regression where libdecnumber sub objects weren't
    built with -fpic and caused segv failure on s390.
  Fixed segv error in printf_dfp() due to negative array index access.
  Exported missing __fabsd* and __fpclassifyd* function prototypes.
  Fixed header include order problem.
* Thu Oct  7 2010 matz@suse.de
- Update to version 1.0.3, fixing several bugs, among
  them wrong strtod32/64/128 behaviour.  [bnc #635803, #635809]
* Tue Feb 23 2010 matz@suse.de
- Package the s390(x) hw-accelerated libdfp into libdir/dfp.
  Compile libdecnumber with -D__STDC_DEC_FP__=200704L to define
  the correct internal symbols.
  [bnc #582176]
* Wed Feb 10 2010 matz@suse.de
- Remove the requires on libdfp-32bit.  [bnc #578613]
* Fri Feb  5 2010 matz@suse.de
- Enable build for s390, otherwise 31bit libs would be missing.
  [bnc #572581 again]
* Thu Jan 21 2010 matz@suse.de
- Update to 1.0.1, build soft-fp plus power6/power7/z9-ec variants,
  add baselibs.conf.  [bnc #572581]
* Fri Nov 20 2009 matz@suse.de
- New package.  [fate #304044, #307062]
